==> open-xchange-documents-backend_7.8.1.orig.tar.bz2: open-xchange-documents-backend-7.8.1/com.openexchange.office.doc.imexport/src/com/openexchange/office/doc/imexport/ImporterPropertyHelper.java <==
package com.openexchange.office.doc.imexport;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.DocumentProperties;
import com.openexchange.office.tools.memory.MemoryObserver;
import com.openexchange.office.tools.system.SystemInfoHelper;

public class ImporterPropertyHelper {

    /**
     * Sets the importer properties regarding memory information to prevent
     * out-of-memory exceptions, while loading big documents.
     *
     * @param importerProps The json object that is used for importer properties.
     *
     * @return The maximum memory to be used by the import filter.
     */
    public static long setMemoryImporterProperties(final JSONObject importerProps) {
        long maxHeapSizeForFilter = 0;

        final SystemInfoHelper.MemoryInfo memInfo = SystemInfoHelper.getMemoryInfo();
        if (null != memInfo) {
            try {
                // The maximal heap size for the filter to load the document should not exceed
                // half of the maximal heap size of the JVM.
                maxHeapSizeForFilter = memInfo.maxHeapSize / 2;
                importerProps.put("maxMemoryUsage", maxHeapSizeForFilter);

                double percentage = ((double)(memInfo.maxHeapSize - SystemInfoHelper.MINIMAL_FREE_BACKEND_HEAPSPACE)) / (double)memInfo.maxHeapSize;
                MemoryObserver memObserver = MemoryObserver.getMemoryObserver();
                MemoryObserver.setPercentageUsageThreshold(percentage);

                importerProps.put(DocumentProperties.PROP_MEMORYOBSERVER, memObserver);
                importerProps.put(DocumentProperties.PROP_MAX_MEMORY_USAGE, maxHeapSizeForFilter);
            } catch (JSONException e) {
                //LOG.error("Exception caught while setting up importer memory properties", e);
            }
        }

        return maxHeapSizeForFilter;
    }

}

==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.doc.imexport/src/com/openexchange/office/doc/imexport/ImporterPropertyHelper.java <==
package com.openexchange.office.doc.imexport;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.DocumentProperties;
import com.openexchange.office.tools.memory.MemoryObserver;
import com.openexchange.office.tools.system.SystemInfoHelper;

public class ImporterPropertyHelper {

    /**
     * Sets the importer properties regarding memory information to prevent
     * out-of-memory exceptions, while loading big documents.
     *
     * @param importerProps The json object that is used for importer properties.
     *
     * @return The maximum memory to be used by the import filter.
     */
    public static long setMemoryImporterProperties(final JSONObject importerProps) {
        long maxHeapSizeForFilter = 0;

        final SystemInfoHelper.MemoryInfo memInfo = SystemInfoHelper.getMemoryInfo();
        if (null != memInfo) {
            try {
                // The maximal heap size for the filter to load the document should not exceed
                // half of the maximal heap size of the JVM. The filter uses the value to
                // prevent loading documents that need a huge amount of heap memory.
                maxHeapSizeForFilter = memInfo.maxHeapSize / 2;
                importerProps.put("maxMemoryUsage", maxHeapSizeForFilter);

                MemoryObserver memObserver = MemoryObserver.getMemoryObserver();

                importerProps.put(DocumentProperties.PROP_MEMORYOBSERVER, memObserver);
                importerProps.put(DocumentProperties.PROP_MAX_MEMORY_USAGE, maxHeapSizeForFilter);
            } catch (JSONException e) {
                //LOG.error("Exception caught while setting up importer memory properties", e);
            }
        }

        return maxHeapSizeForFilter;
    }

}
